@@ -1,4 +1,5 @@
-from dataclasses import field as dataclasses_field, make_dataclass
+from dataclasses import field as dataclasses_field
+from dataclasses import make_dataclass
 
 import pydantic
 import strawberry
@@ -7,10 +8,9 @@ from strawberry.field import StrawberryField
 from .types import FieldError
 
 
-
 def create_root_type(fields):
     cls = make_dataclass(
-        'RootType',
+        "RootType",
         fields=[
             (
                 field._field_definition.origin_name,
@@ -23,6 +23,7 @@ def create_root_type(fields):
 
     return strawberry.type(cls)
 
+
 def create_validation_error_type(prefix: str, type_: StrawberryField):
     @classmethod
     def from_validation_error(cls, validation_error: pydantic.ValidationError):
